from setuptools import setup

setup(
    name = 'seiRJ',
    version = '1.0.4',
    author = 'Joao Campbell',
    author_email = 'jpcampbell2004@gmail.com',
    packages = ['seiRJ'],
    description = 'Acesso ao SEI-RJ',
    long_description = 'Acesso ao SEI-RJ para tarefas de automação',
    url = 'https://github.com/joaocampbell2',
    project_urls = {
        'Código fonte': 'https://github.com/joaocampbell2',
        'Download': 'https://github.com/joaocampbell2'
    },
    license = 'MIT',
    keywords = 'seiRJ',
    classifiers = [
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: Portuguese (Brazilian)',
        'Operating System :: OS Independent',
        'Topic :: Software Development :: Internationalization',
        'Topic :: Scientific/Engineering :: Physics'
    ]
)


